@@ -8,10 +8,11 @@ from datetime import datetime
 from json import dumps
 
 import requests.exceptions
+from rich.console import Console
 
 import darwin.cli_functions as f
 from darwin import __version__
-from darwin.exceptions import InvalidTeam, Unauthenticated, Unauthorized
+from darwin.exceptions import GracefulExit, InvalidTeam, Unauthenticated, Unauthorized
 from darwin.options import Options
 
 
@@ -43,21 +44,14 @@ def main() -> None:
         f._error("The team specified is not in the configuration, please authenticate first.")
     except requests.exceptions.ConnectionError:
         f._error("Darwin seems unreachable, please try again in a minute or contact support.")
-    except Exception as e:  # Catch unhandled exceptions
-        filename = f"darwin_error_{datetime.now().timestamp()}.log"
+    except GracefulExit as e:
+        f.error(e.message)
+    except Exception:  # Catch unhandled exceptions
+        console = Console()
+        console.print("An unexpected error occurred, please contact support, and send them the file.")
+        console.print_exception()
 
-        fd = open(filename, "w")
-        fd.write("Darwin CLI error log")
-        fd.write(f"Version: {__version__}")
-        fd.write(f"OS: {platform.platform()}")
-        fd.write(f"Command: {str(args)}")
-        fd.write(f"Error: {str(e)}")
-        fd.close()
-
-        f._error(
-            f"An unexpected error occurred, errors have been written to {filename}, please contact support, and send them the file."
-            + f"Error: {str(e)}"
-        )
+        exit(255)
 
 
 def _run(args: Namespace, parser: ArgumentParser) -> None:
@@ -134,7 +128,14 @@ def _run(args: Namespace, parser: ArgumentParser) -> None:
         elif args.action == "releases":
             f.dataset_list_releases(args.dataset)
         elif args.action == "pull":
-            f.pull_dataset(args.dataset, args.only_annotations, args.folders, args.video_frames, args.force_slots)
+            f.pull_dataset(
+                args.dataset,
+                args.only_annotations,
+                args.folders,
+                args.video_frames,
+                args.force_slots,
+                args.ignore_slots,
+            )
         elif args.action == "import":
             f.dataset_import(
                 args.dataset,
@@ -146,7 +147,7 @@ def _run(args: Namespace, parser: ArgumentParser) -> None:
                 args.import_annotators,
                 args.import_reviewers,
                 cpu_limit=args.cpu_limit,
-            ),
+            )
         elif args.action == "convert":
             f.dataset_convert(args.dataset, args.format, args.output_dir)
         elif args.action == "set-file-status":
