@@ -190,6 +190,7 @@ class RemoteDataset(ABC):
         use_folders: bool = False,
         video_frames: bool = False,
         force_slots: bool = False,
+        ignore_slots: bool = False,
     ) -> Tuple[Optional[Callable[[], Iterator[Any]]], int]:
         """
         Downloads a remote dataset (images and annotations) to the datasets directory.
@@ -235,6 +236,9 @@ class RemoteDataset(ABC):
         ValueError
             If darwin in unable to get ``Team`` configuration.
         """
+
+        console = self.console or Console()
+
         if release is None:
             release = self.get_release()
 
@@ -318,6 +322,7 @@ class RemoteDataset(ABC):
             use_folders=use_folders,
             video_frames=video_frames,
             force_slots=force_slots,
+            ignore_slots=ignore_slots,
         )
         if count == 0:
             return None, count
@@ -329,7 +334,18 @@ class RemoteDataset(ABC):
             if env_max_workers and int(env_max_workers) > 0:
                 max_workers = int(env_max_workers)
 
-            exhaust_generator(progress=progress(), count=count, multi_threaded=multi_threaded, worker_count=max_workers)
+            console.print(f"Going to download {str(count)} files to {self.local_images_path.as_posix()}.")
+            successes, errors = exhaust_generator(
+                progress=progress(), count=count, multi_threaded=multi_threaded, worker_count=max_workers
+            )
+            if errors:
+                self.console.print(f"Encountered errors downloading {len(errors)} files")
+            for error in errors:
+                self.console.print(f"\t - {error}")
+
+            downloaded_file_count = len([f for f in self.local_images_path.rglob("*") if f.is_file()])
+            console.print(f"Total file count after download completed {str(downloaded_file_count)}.")
+
             return None, count
         else:
             return progress, count
