@@ -22,12 +22,7 @@ from darwin.item import DatasetItem
 
 Unknown = Any  # type: ignore
 
-try:
-    from mpire import WorkerPool, tqdm
-
-    MPIRE_AVAILABLE = True
-except ImportError:
-    MPIRE_AVAILABLE = False
+from tqdm import tqdm
 
 if TYPE_CHECKING:
     from darwin.client import Client
@@ -44,6 +39,13 @@ from darwin.exceptions import IncompatibleOptions, RequestEntitySizeExceeded
 from darwin.utils import flatten_list, secure_continue_request
 from darwin.version import __version__
 
+try:
+    from mpire import WorkerPool
+
+    MPIRE_AVAILABLE = True
+except ImportError:
+    MPIRE_AVAILABLE = False
+
 # Classes missing import support on backend side
 UNSUPPORTED_CLASSES = ["string", "graph"]
 
@@ -125,7 +127,7 @@ def find_and_parse(
 
     maybe_console(f"Found {len(files)} files")
 
-    if use_multi_cpu and MPIRE_AVAILABLE:
+    if use_multi_cpu and MPIRE_AVAILABLE and cpu_limit > 1:
         maybe_console(f"Using multiprocessing with {cpu_limit} workers")
         try:
             with WorkerPool(cpu_limit) as pool:
@@ -138,15 +140,16 @@ def find_and_parse(
             return None
 
     else:
-        if use_multi_cpu and not MPIRE_AVAILABLE:
-            maybe_console("Using single CPU for upload. Run pip install mpire to benefit from faster uploads.")
-        else:
-            maybe_console("Using single CPU")
+        maybe_console("Using single CPU")
         parsed_files = list(map(importer, tqdm(files) if is_console else files))
 
     maybe_console("Finished.")
-
-    if not isinstance(parsed_files, list):
+    # Sometimes we have a list of lists of AnnotationFile, sometimes we have a list of AnnotationFile
+    # We flatten the list of lists
+    if isinstance(parsed_files, list):
+        if isinstance(parsed_files[0], list):
+            parsed_files = [item for sublist in parsed_files for item in sublist]
+    else:
         parsed_files = [parsed_files]
 
     parsed_files = [f for f in parsed_files if f is not None]
@@ -249,7 +252,7 @@ def import_annotations(
     delete_for_empty: bool = False,
     import_annotators: bool = False,
     import_reviewers: bool = False,
-    use_multi_cpu: bool = True,
+    use_multi_cpu: bool = False,  # Set to False to give time to resolve MP behaviours
     cpu_limit: Optional[int] = None,  # 0 because it's set later in logic
 ) -> None:
     """
@@ -478,6 +481,8 @@ def import_annotations(
             for parsed_file in track(files_to_track):
 
                 image_id, default_slot_name = remote_files[parsed_file.full_path]
+                if parsed_file.slots:
+                    default_slot_name = parsed_file.slots[0].name
 
                 errors, succes = _import_annotations(
                     dataset.client,
